aboutsummaryrefslogtreecommitdiff
path: root/nix
diff options
context:
space:
mode:
authorSefa Eyeoglu <contact@scrumplex.net>2022-10-18 13:05:24 +0200
committerGitHub <noreply@github.com>2022-10-18 13:05:24 +0200
commitafaef4e83bd3d680897762554a23be9c55d3f901 (patch)
tree7b790479e44e0f6d07dabc660f627c6249afa227 /nix
parent981e9cf290b4b65bf308a82336f69325b504398a (diff)
parentb746f723cb32ef066bea48a1a2765b3ec6b7003c (diff)
downloadPrismLauncher-afaef4e83bd3d680897762554a23be9c55d3f901.tar.gz
PrismLauncher-afaef4e83bd3d680897762554a23be9c55d3f901.tar.bz2
PrismLauncher-afaef4e83bd3d680897762554a23be9c55d3f901.zip
Merge pull request #13 from PlaceholderMC/rebrand
Diffstat (limited to 'nix')
-rw-r--r--nix/default.nix14
1 files changed, 7 insertions, 7 deletions
diff --git a/nix/default.nix b/nix/default.nix
index 19136cad..c8b4f7cc 100644
--- a/nix/default.nix
+++ b/nix/default.nix
@@ -38,14 +38,14 @@ let
libGL
];
# This variable will be passed to Minecraft by PolyMC
gameLibraryPath = libpath + ":/run/opengl-driver/lib";
javaPaths = lib.makeSearchPath "bin/java" ([ jdk jdk8 ] ++ extraJDKs);
in
stdenv.mkDerivation rec {
- pname = "polymc";
+ pname = "prismlauncher";
inherit version;
src = lib.cleanSource self;
@@ -77,17 +77,17 @@ stdenv.mkDerivation rec {
# we have to check if the system is NixOS before adding stdenv.cc.cc.lib (#923)
postInstall = ''
# xorg.xrandr needed for LWJGL [2.9.2, 3) https://github.com/LWJGL/lwjgl/issues/128
- wrapQtApp $out/bin/polymc \
+ wrapQtApp $out/bin/prismlauncher \
--run '[ -f /etc/NIXOS ] && export LD_LIBRARY_PATH="${stdenv.cc.cc.lib}/lib:$LD_LIBRARY_PATH"' \
--prefix LD_LIBRARY_PATH : ${gameLibraryPath} \
- --prefix POLYMC_JAVA_PATHS : ${javaPaths} \
+ --prefix PRISMLAUNCHER_JAVA_PATHS : ${javaPaths} \
--prefix PATH : ${lib.makeBinPath [ xorg.xrandr ]}
'';
meta = with lib; {
- homepage = "https://polymc.org/";
- downloadPage = "https://polymc.org/download/";
- changelog = "https://github.com/PolyMC/PolyMC/releases";
+ homepage = "https://prismlauncher.org/";
+ downloadPage = "https://prismlauncher.org/download/";
+ changelog = "https://github.com/PrismLauncher/PrismLauncher/releases";
description = "A free, open source launcher for Minecraft";
longDescription = ''
Allows you to have multiple, separate instances of Minecraft (each with
@@ -38,14 +38,14 @@ let
libGL
];
- # This variable will be passed to Minecraft by PolyMC
+ # This variable will be passed to Minecraft by Prism Launcher
gameLibraryPath = libpath + ":/run/opengl-driver/lib";
javaPaths = lib.makeSearchPath "bin/java" ([ jdk jdk8 ] ++ extraJDKs);